# Mognet

Mognet is a fast, simple framework to build distributed applications using task queues.

## Installing

Mognet can be installed via pip, with:

```
pip install mognet
```

## Getting Started and Documentation

We recommend having a look at the [Documentation](https://ibm.github.io/project-mognet/).

## Contributing

Please read [Contributing to Mognet](./CONTRIBUTING.md) for details.


## References

If you use `Mognet` in your projects, please consider citing the following:

```bib
@software{Project Mognet,
author = {DeepSearch Team},
month = {4},
title = {{Project Mognet}},
url = {https://github.com/IBM/project-mognet},
version = {main},
year = {2022}
}
```

## License

The `Mognet` codebase is under MIT license.
For individual model usage, please refer to the model licenses found in the original packages.
